package com.qmth.cqb.paper.service;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.qmth.cqb.paper.dao.PaperDetailUnitRepo;
import com.qmth.cqb.paper.dto.PaperDetailUnitExp;
import com.qmth.cqb.paper.model.Paper;
import com.qmth.cqb.paper.model.PaperDetail;
import com.qmth.cqb.paper.model.PaperDetailUnit;
import com.qmth.cqb.question.dao.QuesRepo;
import com.qmth.cqb.question.model.Question;
import com.qmth.cqb.question.service.QuesService;

@Service
public class PaperDetailUnitService {

    @Autowired
    PaperDetailUnitRepo paperDetailUnitRepo;

    @Autowired
    QuesService quesService;

    @Autowired
    QuesRepo quesRepo;

    @Autowired
    PaperService paperService;

    /**
     * 根据Id获得对应的试题对象
     * 
     * @param id
     * @return
     */
    public Question getQuestionByPaperDetailUnitId(String id) {
        return paperDetailUnitRepo.findOne(id).getQuestion();
    }

    /**
     * 按ID查询小题
     * 
     * @param id
     * @return
     */
    public PaperDetailUnit findById(String id) {
        return paperDetailUnitRepo.findOne(id);
    }

    /**
     * 保存小题
     * 
     * @param pdu
     * @return
     */
    public PaperDetailUnit savePaperDetailUnit(PaperDetailUnitExp pduExp) {
        PaperDetailUnit oldPdu = paperDetailUnitRepo.findOne(pduExp.getId());
        oldPdu.setScore(pduExp.getScore());
        oldPdu.setQuestion(pduExp.getQuestion());
        Question ques = pduExp.getQuestion();
        quesRepo.save(ques);// 同时要跟新小题里面的Qustion对象
        return paperDetailUnitRepo.save(oldPdu);
    }

    /**
     * 删除小题
     * 
     * @param id
     * @return
     */
    public void deletePaperDetailUnit(String id) {
        Paper paper = paperDetailUnitRepo.findOne(id).getPaper();
        paperDetailUnitRepo.delete(id);
        paperService.formatPaper(paper);
    }

    /**
     * 根据大题查小题
     * 
     * @param paperDetail
     * @return
     */
    public List<PaperDetailUnit> getUnitsByPaperDetail(PaperDetail paperDetail) {
        return paperDetailUnitRepo.findByPaperDetail(paperDetail);
    }

    /**
     * 根据大题集合删除小题
     * 
     * @param paperDetails
     */
    public void deleteUnitsByPaperDetails(List<PaperDetail> paperDetails) {
        List<PaperDetailUnit> units = new ArrayList<PaperDetailUnit>();
        for (PaperDetail pd : paperDetails) {
            units.addAll(getUnitsByPaperDetail(pd));
        }
        paperDetailUnitRepo.delete(units);
    }
}
